# pied-piper
An Agent-Based Model Framework for simulating society resilience


![Pied Piper of Hamelin](https://upload.wikimedia.org/wikipedia/commons/thumb/d/d9/Pied_Piper2.jpg/593px-Pied_Piper2.jpg)

Named after "Pied Piper of Hamelin," the title character of a legend from the town of Hamelin in Germany

## Introduction

Whenever environments condition change for species, the living entities start to react to the new new condition. This projects aims at modeling the Alaskan communities that are heavily affected by the global warming.

## Installation

Install the package using pip:
```sh
pip install piperabm
```